@@ -38,6 +38,7 @@ __all__ = (
     "CreateDBInstanceResultTypeDef",
     "CreateDBSubnetGroupResultTypeDef",
     "CreateEventSubscriptionResultTypeDef",
+    "CreateGlobalClusterResultTypeDef",
     "DBClusterMemberTypeDef",
     "DBClusterMessageTypeDef",
     "DBClusterParameterGroupDetailsTypeDef",
@@ -61,6 +62,7 @@ __all__ = (
     "DeleteDBClusterSnapshotResultTypeDef",
     "DeleteDBInstanceResultTypeDef",
     "DeleteEventSubscriptionResultTypeDef",
+    "DeleteGlobalClusterResultTypeDef",
     "DescribeDBClusterSnapshotAttributesResultTypeDef",
     "DescribeEngineDefaultClusterParametersResultTypeDef",
     "EndpointTypeDef",
@@ -73,11 +75,15 @@ __all__ = (
     "EventsMessageTypeDef",
     "FailoverDBClusterResultTypeDef",
     "FilterTypeDef",
+    "GlobalClusterMemberTypeDef",
+    "GlobalClusterTypeDef",
+    "GlobalClustersMessageTypeDef",
     "ModifyDBClusterResultTypeDef",
     "ModifyDBClusterSnapshotAttributeResultTypeDef",
     "ModifyDBInstanceResultTypeDef",
     "ModifyDBSubnetGroupResultTypeDef",
     "ModifyEventSubscriptionResultTypeDef",
+    "ModifyGlobalClusterResultTypeDef",
     "OrderableDBInstanceOptionTypeDef",
     "OrderableDBInstanceOptionsMessageTypeDef",
     "PaginatorConfigTypeDef",
@@ -87,6 +93,7 @@ __all__ = (
     "PendingMaintenanceActionsMessageTypeDef",
     "PendingModifiedValuesTypeDef",
     "RebootDBInstanceResultTypeDef",
+    "RemoveFromGlobalClusterResultTypeDef",
     "RemoveSourceIdentifierFromSubscriptionResultTypeDef",
     "ResourcePendingMaintenanceActionsTypeDef",
     "RestoreDBClusterFromSnapshotResultTypeDef",
@@ -220,6 +227,14 @@ CreateEventSubscriptionResultTypeDef = TypedDict(
     total=False,
 )
 
+CreateGlobalClusterResultTypeDef = TypedDict(
+    "CreateGlobalClusterResultTypeDef",
+    {
+        "GlobalCluster": "GlobalClusterTypeDef",
+    },
+    total=False,
+)
+
 DBClusterMemberTypeDef = TypedDict(
     "DBClusterMemberTypeDef",
     {
@@ -358,6 +373,8 @@ DBClusterTypeDef = TypedDict(
         "MasterUsername": str,
         "PreferredBackupWindow": str,
         "PreferredMaintenanceWindow": str,
+        "ReplicationSourceIdentifier": str,
+        "ReadReplicaIdentifiers": List[str],
         "DBClusterMembers": List["DBClusterMemberTypeDef"],
         "VpcSecurityGroups": List["VpcSecurityGroupMembershipTypeDef"],
         "HostedZoneId": str,
@@ -504,6 +521,14 @@ DeleteEventSubscriptionResultTypeDef = TypedDict(
     total=False,
 )
 
+DeleteGlobalClusterResultTypeDef = TypedDict(
+    "DeleteGlobalClusterResultTypeDef",
+    {
+        "GlobalCluster": "GlobalClusterTypeDef",
+    },
+    total=False,
+)
+
 DescribeDBClusterSnapshotAttributesResultTypeDef = TypedDict(
     "DescribeDBClusterSnapshotAttributesResultTypeDef",
     {
@@ -621,6 +646,42 @@ FilterTypeDef = TypedDict(
     },
 )
 
+GlobalClusterMemberTypeDef = TypedDict(
+    "GlobalClusterMemberTypeDef",
+    {
+        "DBClusterArn": str,
+        "Readers": List[str],
+        "IsWriter": bool,
+    },
+    total=False,
+)
+
+GlobalClusterTypeDef = TypedDict(
+    "GlobalClusterTypeDef",
+    {
+        "GlobalClusterIdentifier": str,
+        "GlobalClusterResourceId": str,
+        "GlobalClusterArn": str,
+        "Status": str,
+        "Engine": str,
+        "EngineVersion": str,
+        "DatabaseName": str,
+        "StorageEncrypted": bool,
+        "DeletionProtection": bool,
+        "GlobalClusterMembers": List["GlobalClusterMemberTypeDef"],
+    },
+    total=False,
+)
+
+GlobalClustersMessageTypeDef = TypedDict(
+    "GlobalClustersMessageTypeDef",
+    {
+        "Marker": str,
+        "GlobalClusters": List["GlobalClusterTypeDef"],
+    },
+    total=False,
+)
+
 ModifyDBClusterResultTypeDef = TypedDict(
     "ModifyDBClusterResultTypeDef",
     {
@@ -661,6 +722,14 @@ ModifyEventSubscriptionResultTypeDef = TypedDict(
     total=False,
 )
 
+ModifyGlobalClusterResultTypeDef = TypedDict(
+    "ModifyGlobalClusterResultTypeDef",
+    {
+        "GlobalCluster": "GlobalClusterTypeDef",
+    },
+    total=False,
+)
+
 OrderableDBInstanceOptionTypeDef = TypedDict(
     "OrderableDBInstanceOptionTypeDef",
     {
@@ -770,6 +839,14 @@ RebootDBInstanceResultTypeDef = TypedDict(
     total=False,
 )
 
+RemoveFromGlobalClusterResultTypeDef = TypedDict(
+    "RemoveFromGlobalClusterResultTypeDef",
+    {
+        "GlobalCluster": "GlobalClusterTypeDef",
+    },
+    total=False,
+)
+
 RemoveSourceIdentifierFromSubscriptionResultTypeDef = TypedDict(
     "RemoveSourceIdentifierFromSubscriptionResultTypeDef",
     {
